@@ -149,6 +149,9 @@ def _run_env(args):
     if project is None:
         LOGGER.fatal(f"'project' must be provided in '.avtoolbox.yml'. Wasn't found, cannot continue.")
         return
+    elif any(c.isupper() for c in project):
+        LOGGER.fatal(f"'project' is set to '{project}' which is not allowed since it has capital letters. Please choose a name with only lowercase.")
+        return
 
     username = get_attr("user", "name", default=os.getlogin())
     uid = get_attr("user", "uid", default=os.getuid())
@@ -158,9 +161,13 @@ def _run_env(args):
     dev_dockerfile, dev_dockerfile_path = read_data("docker", "dev", "dev.dockerfile")
     apt_dependencies = ' '.join(get_attr("dev", "apt-dependencies", default=""))
     pip_requirements = ' '.join(get_attr("dev", "pip-requirements", default=""))
-    scripts = get_attr("dev", "scripts", default=os.path.join("docker", "dev", "scripts"))
     ports = get_attr("dev", "ports", default=[])
 
+    scripts = get_attr("dev", "scripts", default=os.path.join("docker", "dev", "scripts"))
+    if not os.path.isdir(root / scripts):
+        LOGGER.fatal(f"dev.scripts must be a directory, got '{scripts}'")
+        return
+
     # ROS
     workspace = get_attr("ros", "workspace", default="workspace")
     distro = get_attr("ros", "distro", default="galactic")
@@ -249,17 +256,18 @@ def _run_env(args):
                 LOGGER.info(f"Building...")
                 client.compose.build()
 
+            # Ignore all running services
+            services = {name : service for name, service in config['services'].items() if len(docker.container.list(filters={"name": service["container_name"]})) == 0 }
+
+            # If all the services are already running, don't try to spin up
+            if len(services) == 0:
+                LOGGER.warn(f"No services need to be initialized. Turning off 'up'. If you didn't explicitly call 'up', this may be safely ignored.")
+                args.up = False
+
             if args.up:
                 LOGGER.info(f"Spinning up...")
 
-                # Ignore all running services
-                config['services'] = {name : service for name, service in config['services'].items() if len(docker.container.list(filters={"name": service["container_name"]})) == 0 }
-
-                # If all the services are already running, don't try to spin up
-                if len(config['services']) == 0:
-                    LOGGER.warn(f"No services need to be initialized. Turning off 'up'. If you didn't explicitly call 'up', this may be safely ignored.")
-                    args.up = False
-
+                config['services'] = services
                 for service_name, service in config['services'].items():
 
                     # For each port in each service, make sure they map to available ports
@@ -284,9 +292,10 @@ def _run_env(args):
                             target = port['target'] if isinstance(port, dict) else port.split(":")[1]
                             if _is_port_in_use(published):
                                 LOGGER.warn(f"Tried to map container port '{target}' to host port '{published}' for service '{service_name}', but it is in use. Trying again with '{published + 1}'.")
-                                published += 1
                                 if isinstance(port, str):
-                                    port = f"{published}:{target}"
+                                    port = f"{published + 1}:{target}"
+                                else:
+                                    port['published'] += 1
                             else:
                                 break
 
